| Title: | Easy Calculation and Visualisation of Confidence Intervals |
|---|---|
| Description: | Functions to speed up the exploratory analysis of simple datasets using 'dplyr'. Functions are provided to do the common tasks of calculating confidence intervals. |
| Authors: | Conor Neilson [aut, cre] |
| Maintainer: | Conor Neilson <[email protected]> |
| License: | GPL-3 |
| Version: | 2.3.1.9000 |
| Built: | 2026-05-11 07:17:46 UTC |
| Source: | https://github.com/condwanaland/summariser |
Functions from dplyr are used to automate the process of calculating basic summary statistics on a data frame. Returned statistics include mean, standard deviation, standard error, count, and 95 confidence intervals from a normal distribution (summary_stats) and from a t-distribution (summary_stats.t)
summary_stats(data, measure, type)summary_stats(data, measure, type)
data |
a data frame |
measure |
a numeric variable. Response variable - summary statistics will be returned for this variable |
type |
a string variable. Controls whether a normal or t distribution is used for CI calculation. Defaults to "norm". |
library(summariser) library(dplyr) iris %>% summary_stats(Sepal.Length)library(summariser) library(dplyr) iris %>% summary_stats(Sepal.Length)